
<h1 align="center">
  <img src="https://github.com/idanpa/jupad/raw/main/jupad/resources/icon.svg" height="40" style="vertical-align:bottom"> jupad - Python Notepad
</h1>


Python as a calculator, notepad style.  

Inspired by notepad calculators ([Soulver](https://soulver.app/), [Numi](https://numi.app/), [Numbr](https://numbr.dev/)), reactive jupyter notebooks ([marimo](https://github.com/marimo-team/marimo), [ipyflow](https://github.com/ipyflow)) and similar projects ([Hydrogen](https://github.com/nteract/hydrogen)).  

Based on [qtconsole](https://github.com/jupyter/qtconsole).

## Usage
```
jupad
```

<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://github.com/idanpa/jupad/raw/main/docs/demo.gif">
    <source media="(prefers-color-scheme: light)" srcset="https://github.com/idanpa/jupad/raw/main/docs/demo.gif">
    <img src="https://github.com/idanpa/jupad/raw/main/docs/demo.gif">
  </picture>
</p>

## Installation 
```
pip install jupad
```
